'''
socket extention api.
builds on the standart socket library and adds more advance functions,
making it easier to make more varied sockets.
'''
try:
	from .sug_sock import *
except:
	print('[-] sug_sock library not found')
try:
	import os
except:
	print('[-] os library not found')

def debug():
	print('debug function: ')
	print(dir(sug_sock)) 
	print(dir(os))
	print(os.getcwd())

def meme():
	print("nice")


'''
socket extention api.
builds on the standart socket library and adds more advance functions,
making it easier to make more varied sockets.

so the sugsock would contain a regular socket object, with easy functions
stuff in a sock:
	port
	ip
	protocol
	
'''
try:
	import socket
except:
	print("[-] socket library not found")
	exit(1)
try:
    import threading
except:
	print("[-] threading library not found")
	exit(1)
class sugsock:
	def __init__(self):
		self.sock = socket.socket()
		